@@ -13,6 +13,7 @@ from io import BytesIO, StringIO
 from pathlib import Path
 from uuid import uuid4
 
+import pytest
 from MarkupPy import markup
 from openpyxl.reader.excel import load_workbook
 
@@ -21,6 +22,11 @@ from tablib.core import Row, detect_format
 from tablib.exceptions import UnsupportedFormat
 from tablib.formats import registry
 
+try:
+    import pandas
+except ImportError:  # pragma: no cover
+    pandas = None
+
 
 class BaseTestCase(unittest.TestCase):
     def setUp(self):
@@ -264,6 +270,7 @@ class TablibTestCase(BaseTestCase):
             'c|3'
         ])
 
+    @pytest.mark.skipif(pandas is None, reason="pandas is not installed")
     def test_unicode_append(self):
         """Passes in a single unicode character and exports."""
 
@@ -272,6 +279,7 @@ class TablibTestCase(BaseTestCase):
         data.append(new_row)
         self._test_export_data_in_all_formats(data)
 
+    @pytest.mark.skipif(pandas is None, reason="pandas is not installed")
     def test_datetime_append(self):
         """Passes in a single datetime and a single date and exports."""
 
@@ -283,6 +291,7 @@ class TablibTestCase(BaseTestCase):
         data.append(new_row)
         self._test_export_data_in_all_formats(data)
 
+    @pytest.mark.skipif(pandas is None, reason="pandas is not installed")
     def test_separator_append(self):
         for a in range(3):
             data.append_separator('foobar')
@@ -313,13 +322,13 @@ class TablibTestCase(BaseTestCase):
 
     def test_book_import_from_file(self):
         xlsx_source = Path(__file__).parent / 'files' / 'founders.xlsx'
-        with open(str(xlsx_source), mode='rb') as fh:
+        with xlsx_source.open('rb') as fh:
             book = tablib.Databook().load(fh, 'xlsx')
         self.assertEqual(eval(book.json)[0]['title'], 'Feuille1')
 
     def test_dataset_import_from_file(self):
         xlsx_source = Path(__file__).parent / 'files' / 'founders.xlsx'
-        with open(str(xlsx_source), mode='rb') as fh:
+        with xlsx_source.open('rb') as fh:
             dset = tablib.Dataset().load(fh, 'xlsx')
         self.assertEqual(eval(dset.json)[0]['last_name'], 'Adams')
 
@@ -328,6 +337,7 @@ class TablibTestCase(BaseTestCase):
         dset = tablib.Dataset().load(tmp_file, 'yaml')
         self.assertEqual(dset.json, '[]')
 
+    @pytest.mark.skipif(pandas is None, reason="pandas is not installed")
     def test_auto_format_detect(self):
         """Test auto format detection."""
         # html, jira, latex, rst are export only.
@@ -1024,7 +1034,7 @@ class XLSTests(BaseTestCase):
 
     def test_xls_date_import(self):
         xls_source = Path(__file__).parent / 'files' / 'dates.xls'
-        with open(str(xls_source), mode='rb') as fh:
+        with xls_source.open('rb') as fh:
             dset = tablib.Dataset().load(fh, 'xls')
         self.assertEqual(dset.dict[0]['birth_date'], datetime.datetime(2015, 4, 12, 0, 0))
 
@@ -1096,13 +1106,20 @@ class XLSXTests(BaseTestCase):
         new_data = tablib.Databook().load(_xlsx, 'xlsx')
         self.assertEqual(new_data.sheets()[0].title, 'bad name -------qwertyuiopasdfg')
 
-    def test_xlsx_import_set_ragged(self):
-        """Import XLSX file when not all rows have the same length."""
+    def test_xlsx_import_book_ragged(self):
+        """Import XLSX file through databook when not all rows have the same length."""
         xlsx_source = Path(__file__).parent / 'files' / 'ragged.xlsx'
-        with open(str(xlsx_source), mode='rb') as fh:
+        with xlsx_source.open('rb') as fh:
             book = tablib.Databook().load(fh, 'xlsx')
         self.assertEqual(book.sheets()[0].pop(), (1.0, ''))
 
+    def test_xlsx_import_set_ragged(self):
+        """Import XLSX file through dataset when not all rows have the same length."""
+        xlsx_source = Path(__file__).parent / 'files' / 'ragged.xlsx'
+        with xlsx_source.open('rb') as fh:
+            dataset = tablib.Dataset().load(fh, 'xlsx')
+        self.assertEqual(dataset.pop(), (1.0, ''))
+
     def test_xlsx_wrong_char(self):
         """Bad characters are not silently ignored. We let the exception bubble up."""
         from openpyxl.utils.exceptions import IllegalCharacterError
@@ -1317,7 +1334,7 @@ class YAMLTests(BaseTestCase):
     def test_yaml_load(self):
         """ test issue 524: invalid format  """
         yaml_source = Path(__file__).parent / 'files' / 'issue_524.yaml'
-        with yaml_source.open(mode='rb') as fh:
+        with yaml_source.open('rb') as fh:
             with self.assertRaises(UnsupportedFormat):
                 tablib.Dataset().load(fh, 'yaml')
 
